==> die-engine_3.03.orig.tar.gz: die-engine-3.03/XDisasm/dialogdisasmlabels.h <==
// copyright (c) 2019-2020 hors<horsicq@gmail.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
#ifndef DIALOGDISASMLABELS_H
#define DIALOGDISASMLABELS_H

#include <QDialog>
#include <QStandardItemModel>
#include "xdisasm.h"

namespace Ui {
class DialogDisasmLabels;
}

class DialogDisasmLabels : public QDialog
{
    Q_OBJECT

public:
    explicit DialogDisasmLabels(QWidget *pParent,XDisasm::STATS *pDisasmStats);
    ~DialogDisasmLabels();
    qint64 getAddress();

private slots:
    void on_pushButtonClose_clicked();
    void on_pushButtonGoTo_clicked();
    void on_tableViewLabels_doubleClicked(const QModelIndex &index);
    void goTo();

private:
    Ui::DialogDisasmLabels *ui;
    XDisasm::STATS *g_pDisasmStats;
    qint64 g_nAddress;
};

#endif // DIALOGDISASMLABELS_H

==> die-engine_3.07.orig.tar.gz: die-engine-3.07/XDisasm/dialogdisasmlabels.h <==
// copyright (c) 2019-2020 hors<horsicq@gmail.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
#ifndef DIALOGDISASMLABELS_H
#define DIALOGDISASMLABELS_H

#include <QDialog>
#include <QStandardItemModel>

#include "xdisasm.h"

namespace Ui {
class DialogDisasmLabels;
}

class DialogDisasmLabels : public QDialog {
    Q_OBJECT

public:
    explicit DialogDisasmLabels(QWidget *pParent, XDisasm::STATS *pDisasmStats);
    ~DialogDisasmLabels();
    qint64 getAddress();

private slots:
    void on_pushButtonClose_clicked();
    void on_pushButtonGoTo_clicked();
    void on_tableViewLabels_doubleClicked(const QModelIndex &index);
    void goTo();

private:
    Ui::DialogDisasmLabels *ui;
    XDisasm::STATS *g_pDisasmStats;
    qint64 g_nAddress;
};

#endif  // DIALOGDISASMLABELS_H
